aboutsummaryrefslogtreecommitdiffstats
path: root/test/serd_test_util
diff options
context:
space:
mode:
Diffstat (limited to 'test/serd_test_util')
-rw-r--r--test/serd_test_util/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/serd_test_util/__init__.py b/test/serd_test_util/__init__.py
index 4f426009..ac831054 100644
--- a/test/serd_test_util/__init__.py
+++ b/test/serd_test_util/__init__.py
@@ -57,7 +57,7 @@ def wrapper_args(description, with_input=False):
"""Return the command line arguments for a wrapped test."""
parser = argparse.ArgumentParser(description)
- parser.add_argument("--serdi", default="tools/serdi", help="executable")
+ parser.add_argument("--tool", default="tools/serd-pipe", help="executable")
parser.add_argument("--wrapper", default="", help="executable wrapper")
if with_input:
parser.add_argument("input", help="input file")
@@ -149,7 +149,7 @@ def earl_assertion(test, passed, asserter):
def load_rdf(filename, base_uri, command_prefix):
"""Load an RDF file as dictionaries via serdi (only supports URIs)."""
rdf_type = "http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
model = {}
@@ -149,7 +149,7 @@ def earl_assertion(test, passed, asserter):
def load_rdf(filename, base_uri, command_prefix):
- """Load an RDF file as dictionaries via serdi (only supports URIs)."""
+ """Load an RDF file as dictionaries via serd-pipe (only supports URIs)."""
rdf_type = "http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
model = {}